@@ -8,7 +8,7 @@ editable table widget.'
 import csv
 import os
 
-from PyTQt.tqt import TQFrame, TQStringList, TQVBoxLayout, SIGNAL
+from PyTQt.tqt import TQFrame, TQStringList, TQVBoxLayout, TQ_SIGNAL
 from PyTQt.tqttable import TQTable
 
 from tdeui import KTextEdit
