@@ -141,7 +141,7 @@ public:
      *
      * @deprecated
      */
-    KDE_DEPRECATED bool hasBeenFiltered() const { return true; }
+    TDE_DEPRECATED bool hasBeenFiltered() const { return true; }
 
     /**
      * Returns the filtered or the original URL.
@@ -343,7 +343,7 @@ private:
  */
 class TDEIO_EXPORT KURIFilterPlugin : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
 
